using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;

namespace MyCustomNamespace
{
    public class MyTemplatedColumn : GridTemplateColumn
    {
        private const string _myfiltercommand = "myFilterCommand";
        private DateTime? _endSelectedDate;
        private DateTime? _startSelectedDate;

        public override void Initialize()
        {
            base.Initialize();
            Owner.OwnerGrid.ItemCommand += new GridCommandEventHandler(OwnerGrid_ItemCommand);
        }

        public MyTemplatedColumn()
        {
        }

        private string StartPickerId
        {
            get { return string.Format("sdp_{0}", this.UniqueName); }
        }

        private string EndPickerId
        {
            get { return string.Format("edp_{0}", this.UniqueName); }
        }

        private void OwnerGrid_ItemCommand(object source, GridCommandEventArgs e)
        {
            if (e.CommandName == _myfiltercommand)
            {
                RadDatePicker dp1 =
                    ((GridFilteringItem) e.Item)[this.UniqueName].FindControl(StartPickerId) as RadDatePicker;
                RadDatePicker dp2 =
                    ((GridFilteringItem) e.Item)[this.UniqueName].FindControl(EndPickerId) as RadDatePicker;

                if (dp1 != null && dp2 != null)
                {
                    _startSelectedDate = dp1.SelectedDate;
                    _endSelectedDate = dp2.SelectedDate;

                    e.Item.OwnerTableView.FilterExpression =
                        String.Format("{0} >= '{1}' AND {0} <= '{2}'", this.DataField, dp1.SelectedDate, dp2.SelectedDate);
                    e.Item.OwnerTableView.Rebind();
                }
            }
        }

        protected override void SetupFilterControls(TableCell cell)
        {
            RadDatePicker dpStartDate = new RadDatePicker();
            dpStartDate.ID = StartPickerId;
            dpStartDate.DatePopupButton.Visible = false;

            RadDatePicker dpEndDate = new RadDatePicker();
            dpEndDate.DatePopupButton.Visible = false;
            dpEndDate.ID = EndPickerId;
           
            cell.Controls.Add(dpStartDate);
            cell.Controls.Add(new LiteralControl("&nbsp;"));
            cell.Controls.Add(dpEndDate);

            Button btnFilter = new Button();
            btnFilter.ID = string.Format("btnFilter_{0}", this.UniqueName);
            btnFilter.CommandName = _myfiltercommand;
            btnFilter.Text = "Go";

            cell.Controls.Add(new LiteralControl("&nbsp;"));
            cell.Controls.Add(btnFilter);
        }

        protected override void SetCurrentFilterValueToControl(TableCell cell)
        {
            base.SetCurrentFilterValueToControl(cell);
            try
            {
                RadDatePicker dpStartDate = cell.FindControl(StartPickerId) as RadDatePicker;
                RadDatePicker dpEndDate = cell.FindControl(EndPickerId) as RadDatePicker;
                if (dpStartDate != null && _startSelectedDate != DateTime.MinValue)
                {
                    dpStartDate.DbSelectedDate = _startSelectedDate;
                }

                if (dpEndDate != null && _endSelectedDate != DateTime.MinValue)
                {
                    dpEndDate.DbSelectedDate = _endSelectedDate;
                }
            }
            catch (Exception e)
            {
            }
        }
    }
}